==> dde-shell_0.0.40.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Styl wskaźnika</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Ustawienie</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Ustaw do lewej</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Ustaw do góry</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Ustaw do środka</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Ustawienia doku</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Styl wskaźnika</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Tryb klasyczny</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Tryb wyśrodkowany</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozycja</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Ustawienia doku</translation>
    </message>
</context>
</TS>
